==> activity-center-api-0.8.0.3-20171103.082532-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/AlipayPrizeDataDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

/**
 * Created by wubo on 2017/7/17.
 */
public class AlipayPrizeDataDto extends BaseDto{

    /**
     * 活动id
     */
    private Long activityId;

    /**
     *
     */
    private Long prizeId;

    /**
     * 活动标题
     */
    private String title;

    /**
     * 总库存(分)
     */
    private Long totalStock = 0L;
    /**
     * 剩余库存(分)
     */
    private Long Stock = 0L;
    /**
     * 今日消耗(分)
     */
    private Integer todaySale = 0;

    /**
     * 中奖人数
     */
    private Integer awardCount = 0;

    /**
     * 领奖人数
     */
    private Integer acceptCount = 0;

    /**
     * 逾期未领奖金额(分)
     */
    private Integer overdueAmount = 0;

    /**
     * 日期
     */
    private String curDate;

    private Integer alipayType;

    private Integer prizeValue;

    private String prizeType;

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getPrizeId() {
        return prizeId;
    }

    public void setPrizeId(Long prizeId) {
        this.prizeId = prizeId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getTotalStock() {
        return totalStock;
    }

    public void setTotalStock(Long totalStock) {
        this.totalStock = totalStock;
    }

    public Long getStock() {
        return Stock;
    }

    public void setStock(Long stock) {
        Stock = stock;
    }

    public Integer getTodaySale() {
        return todaySale;
    }

    public void setTodaySale(Integer todaySale) {
        this.todaySale = todaySale;
    }

    public Integer getAwardCount() {
        return awardCount;
    }

    public void setAwardCount(Integer awardCount) {
        this.awardCount = awardCount;
    }

    public Integer getAcceptCount() {
        return acceptCount;
    }

    public void setAcceptCount(Integer acceptCount) {
        this.acceptCount = acceptCount;
    }

    public Integer getOverdueAmount() {
        return overdueAmount;
    }

    public void setOverdueAmount(Integer overdueAmount) {
        this.overdueAmount = overdueAmount;
    }

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public Long totalStockIncrement(Long totalStock){
        return this.totalStock += totalStock;
    }

    public Long StockIncrement(Long stock){
        return this.Stock += stock;
    }

    public Integer todaySaleIncrement(Integer todaySale){
        return this.todaySale += todaySale;
    }

    public Integer awardCountIncrement(Integer awardCount){
        return this.awardCount += awardCount;
    }

    public Integer acceptCountIncrement(Integer acceptCount){
        return this.acceptCount += acceptCount;
    }


    public Integer overdueAmountIncrement(Integer overdueAmount){
        return this.overdueAmount += overdueAmount;
    }

    public Integer getAlipayType() {
        return alipayType;
    }

    public void setAlipayType(Integer alipayType) {
        this.alipayType = alipayType;
    }

    public Integer getPrizeValue() {
        return prizeValue;
    }

    public void setPrizeValue(Integer prizeValue) {
        this.prizeValue = prizeValue;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }
}

==> activity-center-api-0.9.1.11-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/AlipayPrizeDataDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

/**
 * Created by wubo on 2017/7/17.
 */
public class AlipayPrizeDataDto extends BaseDto{

    /**
     * 活动id
     */
    private Long activityId;

    /**
     *
     */
    private Long prizeId;

    /**
     * 活动标题
     */
    private String title;

    /**
     * 总库存(分)
     */
    private Long totalStock = 0L;
    /**
     * 剩余库存(分)
     */
    private Long Stock = 0L;
    /**
     * 今日消耗(分)
     */
    private Integer todaySale = 0;

    /**
     * 中奖人数
     */
    private Integer awardCount = 0;

    /**
     * 领奖人数
     */
    private Integer acceptCount = 0;

    /**
     * 逾期未领奖金额(分)
     */
    private Integer overdueAmount = 0;

    /**
     * 日期
     */
    private String curDate;

    /**
     * 订单表中奖项类型
     */
    private Integer alipayType;

    /**
     * 奖品价值
     */
    private Integer prizeValue;

    private String prizeType;

    /** api数值充值充值数量乘以100的结果，和ali order 表中的并不完全相同 */
    private Integer prizeNum;

    /** 逾期未领奖的充值数量乘以100的结果 */
    private Integer overdueNum;

    private Integer activityType;

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getPrizeId() {
        return prizeId;
    }

    public void setPrizeId(Long prizeId) {
        this.prizeId = prizeId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getTotalStock() {
        return totalStock;
    }

    public void setTotalStock(Long totalStock) {
        this.totalStock = totalStock;
    }

    public Long getStock() {
        return Stock;
    }

    public void setStock(Long stock) {
        Stock = stock;
    }

    public Integer getTodaySale() {
        return todaySale;
    }

    public void setTodaySale(Integer todaySale) {
        this.todaySale = todaySale;
    }

    public Integer getAwardCount() {
        return awardCount;
    }

    public void setAwardCount(Integer awardCount) {
        this.awardCount = awardCount;
    }

    public Integer getAcceptCount() {
        return acceptCount;
    }

    public void setAcceptCount(Integer acceptCount) {
        this.acceptCount = acceptCount;
    }

    public Integer getOverdueAmount() {
        return overdueAmount;
    }

    public void setOverdueAmount(Integer overdueAmount) {
        this.overdueAmount = overdueAmount;
    }

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public Long totalStockIncrement(Long totalStock){
        return this.totalStock += totalStock;
    }

    public Long StockIncrement(Long stock){
        return this.Stock += stock;
    }

    public Integer todaySaleIncrement(Integer todaySale){
        return this.todaySale += todaySale;
    }

    public Integer awardCountIncrement(Integer awardCount){
        return this.awardCount += awardCount;
    }

    public Integer acceptCountIncrement(Integer acceptCount){
        return this.acceptCount += acceptCount;
    }


    public Integer overdueAmountIncrement(Integer overdueAmount){
        return this.overdueAmount += overdueAmount;
    }

    public Integer getAlipayType() {
        return alipayType;
    }

    public void setAlipayType(Integer alipayType) {
        this.alipayType = alipayType;
    }

    public Integer getPrizeValue() {
        return prizeValue;
    }

    public void setPrizeValue(Integer prizeValue) {
        this.prizeValue = prizeValue;
    }

    public String getPrizeType() {
        return prizeType;
    }

    public void setPrizeType(String prizeType) {
        this.prizeType = prizeType;
    }

    public Integer getPrizeNum() {
        return prizeNum;
    }

    public void setPrizeNum(Integer prizeNum) {
        this.prizeNum = prizeNum;
    }

    public Integer getOverdueNum() {
        return overdueNum;
    }

    public void setOverdueNum(Integer overdueNum) {
        this.overdueNum = overdueNum;
    }

    public Integer getActivityType() {
        return activityType;
    }

    public void setActivityType(Integer activityType) {
        this.activityType = activityType;
    }
}
